from datetime import datetime
from typing import List, Optional, Dict, Any

from janis_core import *
from janis_core.types.common_data_types import File, Boolean, String, Int, Directory

Caper_List_V0_1_0 = CommandToolBuilder(tool="caper_list", base_command=["caper", "list"], inputs=[ToolInput(tag="in_conf", input_type=File(optional=True), prefix="--conf", doc=InputDocumentation(doc="Specify config file")), ToolInput(tag="in_debug", input_type=Boolean(optional=True), prefix="--debug", doc=InputDocumentation(doc="Prints all logs >= DEBUG level")), ToolInput(tag="in_gcp_service_account_key_json", input_type=File(optional=True), prefix="--gcp-service-account-key-json", doc=InputDocumentation(doc="Secret key JSON file for Google Cloud Platform service\naccount. This service account should have enough\npermission to Storage for client functions and\nStorage/Compute Engine/Genomics API/Life Sciences API\nfor server/runner functions.")), ToolInput(tag="in_port", input_type=String(optional=True), prefix="--port", doc=InputDocumentation(doc="Port for Caper server")), ToolInput(tag="in_no_server_heartbeat", input_type=Boolean(optional=True), prefix="--no-server-heartbeat", doc=InputDocumentation(doc="Disable server heartbeat file.")), ToolInput(tag="in_server_heartbeat_file", input_type=File(optional=True), prefix="--server-heartbeat-file", doc=InputDocumentation(doc="Heartbeat file for Caper clients to get IP and port of\na server")), ToolInput(tag="in_server_heartbeat_timeout", input_type=File(optional=True), prefix="--server-heartbeat-timeout", doc=InputDocumentation(doc="Timeout for a heartbeat file in Milliseconds. A\nheartbeat file older than this interval will be\nignored.")), ToolInput(tag="in_hostname", input_type=String(optional=True), prefix="--hostname", doc=InputDocumentation(doc="Hostname (or IP address) of Caper server.")), ToolInput(tag="in_format", input_type=String(optional=True), prefix="--format", doc=InputDocumentation(doc="Comma-separated list of items to be shown for 'list'\nsubcommand. Any key name in workflow JSON from\nCromwell server's response is allowed. Available keys\nare 'id' (workflow ID), 'status', 'str_label', 'name'\n(WDL/CWL name), 'submission' (date/time), 'start',\n'end' and 'user'. 'str_label' is a special key for\nCaper. See help context of '--str-label' for details")), ToolInput(tag="in_hide_result_before", input_type=Int(optional=True), prefix="--hide-result-before", doc=InputDocumentation(doc="Hide workflows submitted before this date/time. Use\nthe same (or shorter) date/time format shown in 'caper\nlist'. e.g. 2019-06-13, 2019-06-13T10:07")), ToolInput(tag="in_hide_sub_workflow", input_type=Boolean(optional=True), prefix="--hide-subworkflow", doc=InputDocumentation(doc="Hide subworkflows from 'caper list'.")), ToolInput(tag="in_local_loc_dir", input_type=Directory(optional=True), prefix="--local-loc-dir", doc=InputDocumentation(doc="Temporary directory to store Cromwell's intermediate\nbackend files. These files include backend.conf,\nworkflow_opts.json, imports.zip. and localized input\nJSON files due to deepcopying (recursive\nlocalization). Cromwell's MySQL/PostgreSQL DB password\ncan be exposed on backend.conf on this directory.\nTherefore, DO NOT USE /tmp HERE. This directory is\nalso used for storing cached files for\nlocal/slurm/sge/pbs backends.")), ToolInput(tag="in_tmp_gcs_bucket", input_type=Directory(optional=True), prefix="--tmp-gcs-bucket", doc=InputDocumentation(doc="Temporary directory to store cached files for gcp\nbackend. e.g. gs://my-bucket/caper-cache-dir.")), ToolInput(tag="in_tmp_s_three_bucket", input_type=Int(optional=True), prefix="--tmp-s3-bucket", doc=InputDocumentation(doc="Temporary directory to store cached files for aws\nbackend. e.g. s3://my-bucket/caper-cache-dir.\n")), ToolInput(tag="in_wf_id_or_label", input_type=String(), position=0, doc=InputDocumentation(doc="List of workflow IDs to find matching workflows to\ncommit a specified action (list, metadata and abort).\nWildcards (* and ?) are allowed."))], outputs=[], container="quay.io/biocontainers/caper:1.1.0--py_0", version="v0.1.0")


if __name__ == "__main__":
    # or "cwl"
    Caper_List_V0_1_0().translate("wdl")

